Crate aurum_numeric
Source - DivideByZero
- Error which may occur on division by zero.
- IntOverflow
- Error which occurs when an operation causes integer overflow.
- IntUnderflow
- Error which occurs when an operation causes integer underflow.
- ClampError
- Error which may occur when attempting to interpolate between clamped values of different types.
- IntRangeError
- Error which occurs when an operation causes integer overflow or underflow.
- Clamp
- Trait for scalar values which have a “clamped” range.
- ClampFrom
- Trait for interpolation of clamped values between different types.
- ClampInto
- Blanket impl over
ClampFrom. - Lerp
- Trait for linear interpolation.
- One
- Get the multiplicative identity for a numeric type.
- RawFrom
- Trait for raw conversion using the
as operator. - RawInto
- Trait for raw conversion using the
as operator. - Sqrt
- Get the square root of a number.
- TryAdd
- Fallible addition trait.
- TryDiv
- Fallible division trait.
- TryMul
- Fallible multiplication trait.
- TryNeg
- Fallible negation trait.
- TryRem
- Fallible division remainder trait.
- TrySub
- Fallible subtraction trait.
- Zero
- Get the additive identity of a numeric type.